.. module:: pymeasure.instruments.validators

###################
Validator functions
###################

Validators are used in conjunction with the :func:`Instrument.control <pymeasure.instruments.Instrument.control>` or :func:`Instrument.setting <pymeasure.instruments.Instrument.setting>` functions to allow properties with complex restrictions for valid values. They are described in more detail in the :ref:`validators` section.

.. automodule:: pymeasure.instruments.validators
    :members:
    :noindex:
